@@ -15,6 +15,11 @@ except PackageNotFoundError:  # pragma: no cover
 finally:
     del version, PackageNotFoundError
 
-from .interface import extract_dense_array, extract_sparse_array, is_sparse
-from .SparseNdarray import SparseNdarray
+from .DelayedArray import DelayedArray
+from .UnaryIsometricOpSimple import UnaryIsometricOpSimple
 from .UnaryIsometricOpWithArgs import UnaryIsometricOpWithArgs
+from .BinaryIsometricOp import BinaryIsometricOp
+from .Subset import Subset
+from .Combine import Combine
+from .Transpose import Transpose
+from .Cast import Cast
